---
feature_story: FS_94_30_49_28
feature_title: envelope with `help_doc`
feature_status: TODO
---

Help doc is a multi line explanation per `data_envelope` which can be shown like a `man` page.

Unlike `help_hint` (FS_71_87_33_52), it does not affect command line interface look and feel.

Implementation is likely straightforward:
store `help_doc` together with the `data_envelope`.
Alternative way is to search `help_doc` (possibly in a separate collection) based on given `data_envelope` properties.
